@@ -186,7 +186,7 @@
 #' parameter for the stochastic volatility model on the errors. Not returned if \code{sv} is \code{FALSE}.}
 #' \item{\code{MH_diag}}{\emph{(optional)} named list containing statistics for assessing MH performance. Not returned if no MH steps are required
 #' or none of them are specified to be adaptive.}
-#' \item{\code{internals}}{\code{list} object containg two arrays that are required for calculating the LPDS.}
+#' \item{\code{internals}}{\code{list} object containing two arrays that are required for calculating the LPDS.}
 #' \item{\code{priorvals}}{\code{list} object containing hyperparameter values of the prior distributions, as specified by the user.}
 #' \item{\code{model}}{\code{list} object containing the model matrix, model response and formula used.}
 #' \item{\code{summaries}}{\code{list} object containing a collection of summary statistics of the posterior draws.}
@@ -812,7 +812,7 @@ shrinkTVP <- function(formula,
 
     # Create summary of posterior
     if (is.list(res[[i]]) == FALSE & attr(res[[i]], "type") == "sample") {
-      if (i != "theta_sr" & !(i == "sigma2" & sv == TRUE) & i != "beta") {
+      if (i != "theta_sr" & !(i == "sigma2" & sv == TRUE) & i != "beta" & i != "lambda_p" & i != "kappa_p" & i != "psi") {
         res$summaries[[i]] <- t(apply(res[[i]], 2, function(x){
 
           obj <- as.mcmc(x, start = niter - nburn, end = niter, thin = nthin)
@@ -1015,7 +1015,7 @@ shrinkTVP <- function(formula,
 #' @return The value returned is a named list object which can be immediately used as the \code{curr_draws} argument
 #' for another draw from the posterior with \code{updateTVP}. Note that, depending on the model setup, some elements may be matrices of dimension zero.
 #' It contains the following elements:
-#' \item{\code{beta_st}}{dx(N + 1) matrix containing the current draw from the posterior distribtuion of beta.}
+#' \item{\code{beta_st}}{dx(N + 1) matrix containing the current draw from the posterior distribution of beta.}
 #' \item{\code{beta_mean_st}}{dx1 matrix containing the current draws from the posterior distribution of beta_mean.}
 #' \item{\code{theta_sr_st}}{dx1 matrix containing the current draws from the posterior distribution of the square root of theta.}
 #' \item{\code{tau2_st}}{dx1 matrix containing the current draws from the posterior distribution of tau2.}
@@ -1033,8 +1033,8 @@ shrinkTVP <- function(formula,
 #' \item{\code{sv_mu_st}}{number representing the current draw from the posterior distribution of the mu parameter for the stochastic volatility model on the errors.}
 #' \item{\code{sv_phi_st}}{number representing the current draw from the posterior distribution of the phi parameter for the stochastic volatility model on the errors.}
 #' \item{\code{sv_sigma2_st}}{number representing the current draw from the posterior distribution of the sigma2 parameter for the stochastic volatility model on the errors.}
-#' \item{\code{h0_st}}{number representing the current draw from the posterior distribution of the h0 parmater for the stochastic volatility model on the errors.}
-#' \item{\code{internals}}{\code{list} object containg two arrays that are required for calculating the LPDS and bookkeeping objects required for the adaptive MH algorithm to work.}
+#' \item{\code{h0_st}}{number representing the current draw from the posterior distribution of the h0 parameter for the stochastic volatility model on the errors.}
+#' \item{\code{internals}}{\code{list} object containing two arrays that are required for calculating the LPDS and bookkeeping objects required for the adaptive MH algorithm to work.}
 #'
 #' @author Peter Knaus \email{peter.knaus@@wu.ac.at}
 #'
